#
# spec file for package mpc-qt
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mpc-qt
Version:        22.02
Release:        bp154.1.37
Summary:        Media Player Classic Qute Theater
License:        GPL-2.0-only
URL:            https://github.com/cmdrkotori/mpc-qt
Source0:        https://github.com/mpc-qt/mpc-qt/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.changes
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.4
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(mpv) >= 1.101.0
%if 0%{?suse_version} > 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc7-c++
%endif

%description
A clone of Media Player Classic reimplemented in Qt.

%prep
%autosetup -p1
rm -rf mpv-dev

%build
export CXX=g++
test -x "$(type -p g++-7)" && export CXX=g++-7
qmake-qt5 \
  QMAKE_CFLAGS+="%{optflags}" QMAKE_CXXFLAGS+="%{optflags}" \
  QMAKE_CC="${CC}" QMAKE_CXX="${CXX}" PREFIX=%{_prefix} \
  mpc-qt.pro
%make_build

%install
mkdir -p %{buildroot}/%{_bindir} \
         %{buildroot}/%{_datadir}/applications \
         %{buildroot}/%{_datadir}/pixmaps \
         %{buildroot}/%{_datadir}/%{name}/translations
install -m 0755 %{name} %{buildroot}/%{_bindir}
install -m 0644 images/icon/mpc-qt.svg %{buildroot}/%{_datadir}/pixmaps/%{name}.svg
install -m 0644 resources/translations/%{name}_*.qm -t %{buildroot}/%{_datadir}/%{name}/translations
install -m 0644 mpc-qt.desktop %{buildroot}/%{_datadir}/applications/Media\ Player\ Classic\ Qute\ Theater.desktop

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_datadir}/pixmaps/%{name}.svg
%{_datadir}/applications/*.desktop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_datadir}/%{name}/translations/%{name}_*.qm

%changelog
* Sat Feb  5 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 22.02
  * Add mpc-hc compatible web server
  * Process wheel events over entire window
  * Force use of XCB instead of wayland
  * Possibly other improvements not listed here
- Drop mpc-qt-mpv_v2_fix.patch (merged upstream)
* Sun Jan 30 2022 Luigi Baldoni <aloisio@gmx.com>
- Add mpc-qt-mpv_v2_fix.patch (fix Factory build)
* Fri Oct 16 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 20.10
  Fixes and improvements:
  * Add library window, deleted playlists are now saved instead
    of destroyed
  * Remember shown stats page
  * Implement subtitle track preference
  * Rearrange settings window for 720p
  * Save/restore maximized/minimized state
  * Implement additive speed step
  * Correctly set video filters
  * Add ability to save thumbnails
  * Implement after playback -> play next
  * Implement thinner time fields like mpc-hc
  * Implement limiting volume to 100%% like mpc-hc
  * Audio output settings now on own page
  * Add logging framework
  Notes:
  * In addition, there may be other improvements not listed here.
  * As the playlist format has changed, opening the saved data
    of this version with older versions may result in data loss.
- Switch to stable version and remove _service
* Fri Jul  3 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 18.08+git20200704
- Switch again to the original developer's repository
- Add _service
- Drop mpv-qthelper.patch (merged upstream)
* Thu Mar 19 2020 Luigi Baldoni <aloisio@gmx.com>
- Added mpv-qthelper.patch
- Dropped group tag
* Sat Jun 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 18.08+git20190618
  * Unofficial release, all of the available updates before
    the upstream repository was deleted
* Sat Aug  4 2018 aloisio@gmx.com
- Update to version 18.08
  * Saner defaults (volume/zoom/tracks)
  * Add a device manager to implement the Open Disc menu
  * Add subtitles toggle button (#167 #211)
  * Improve usage of the fallback icon theme (#208)
  * Add shortcut to escape fullscreen (#194)
  * Add Spanish translation (#206)
  * Sanitise MPRIS metadata (#203 #204)
  * Implement deltaExtraPlaytimes IPC command (#200)
  * Implement early multi-process (#176)
  * Support Qt 5.11 (#198)
  * Extract tagged version information during the build process
  * Improve the playlist's context menu
  * Implement shuffle mode (#190)
  * Use mpv's new hook API (#189)
  * Fix regression with capitalized file extensions (#186)
  * Fix banding on Wayland (#164)
  * Add high bit-depth screenshotting option (#183)
  * Load mpv Lua scripts at [configfolder]/scripts (#182)
  * Wire up the autoload subs fields
  * Add --freestanding window launch option (#176)
  * Add option to suppress OSD messages (#179)
  * Only accept mouse events over the video widget (#177)
  * Allow the speed step to be customized (#175)
  * Don't add external subfiles to the playlist (#174)
  * Use mpv's internal stats plugin
  * Implement moving to next/previous file in the folder
  * Use mpv's new render API
  * In addition, there may be other changes not listed here.
  * Notes
    + This version is incompatible with older mpv releases. mpv
    0.29.0 requires ffmpeg 4.0
    + The optional device manager functionality requires the
    presence of the udisks2 dbus service. 26e8c19
    + Running mpc-qt with some of the circulating mpv lua
    scripts may void your warranty.
- Dropped mpc-qt-Qt511.patch (merged upstream)
* Mon Jun 11 2018 aloisio@gmx.com
- Added mpc-qt-Qt511.patch to fix build with Qt 5.11
* Sun Mar 11 2018 aloisio@gmx.com
- Update to version 18.03
  * (Re)enable building with older Qt versions (#136)
  * Update mpc-qt.desktop (#165)
  * Fix crash with svp (#140)
  * Bitblit the time and volume sliders (#147)
  * Add custom seek duration (#156)
  * Add Russian translation (#151)
  * Add checkboxes next to the zoom levels (#146)
* Wed Nov  1 2017 aloisio@gmx.com
- Update to version 17.11
  * Remember time of favorites
  * Remember correct config folder (#137)
  * Correct window frame calculation (#138)
  * Don't crash in a new ipc connection (#140)
- Dropped Qt-5.6-backport_setFlag.patch (merged upstream)
* Sun Oct  1 2017 aloisio@gmx.com
- Update to version 17.10
  * Implement favorites menu (use mouse for moving and renaming)
  * Implement mpris protocol (Linux only)
  * Improve .desktop file (Linux only)
  * Fix cli --size implementation (#89)
  * Fix save image filename extension (#127)
  * Use expected window placement on first run (#128)
- Use upstream .desktop file
- Fixed creation date and time
- Added Qt-5.6-backport_setFlag.patch
* Fri Sep  1 2017 aloisio@gmx.com
- Fixed locale path
* Fri Sep  1 2017 aloisio@gmx.com
- Update to version 17.09
  * Export MediaInfo to text file (#119)
  * USe correct mousewheel direction (#118)
  * Premangle the temporary image filename (#120)
  * Don't reset the play speed when pressing play (#117)
  * Honor --size argument (#89)
  * Add palette editor (some shades are drawn by the system on
    Windows)
  * Custom icons and basic themeing (#65)
  * Integration of argon's stats.lua (#104)
  * Populate audio device lists with mpv 0.26.0 (mentioned in #116)
  * Add right-click menu (#113)
  * Simplified resizing code (#114)
* Sun Aug 13 2017 aloisio@gmx.com
- Update to release 17.08
* Sun Jul  2 2017 aloisio@gmx.com
- Update to stable version 17.07
* Tue Jun  6 2017 olaf@aepfle.de
- Adjust usage of gccN-c++ for Leap42 and SLE12
* Wed May 31 2017 aloisio@gmx.com
- Change format for build date
- Add locale file
* Wed Mar  8 2017 aloisio@gmx.com
- Force gcc5 for Leap targets
* Wed Mar  8 2017 opensuse-packaging@opensuse.org
- Update to version 0~git20170308.548cd70:
  * Switch Unix/X11 to Linux behavior for consistency
  * mpvwidget: use undeprecated property names
  * readme: bump required mpv version to 0.24.0
  * remove outdated link
  * openfiledialog: add to project
  * [many]: implement open file dialog
  * readme: fix link to mpc-hc
  * settingswindow: implement video presets
  * settingswindow: remove reference to prescalers
  * qdrawnslider,qdrawnstatus: use QWidget as base class
* Fri Nov 18 2016 aloisio@gmx.com
- Initial package
